load_agent_definitions

Function load_agent_definitions 

pub fn load_agent_definitions(config: &Config) -> Result<Vec<AgentDefinition>>
Load all agent scripts from config and extract their definitions.

For each [agents.script.<name>] entry, reads the script file, creates a temporary Lua VM to extract the agent table metadata, and converts the argument declarations.

Called once at startup.