fn run_lua_agent(
agent: &AgentDefinition,
args: Value,
config: &Config,
) -> Result<AgentPrompt>Expand description
Run the Lua agent synchronously on a blocking thread.
fn run_lua_agent(
agent: &AgentDefinition,
args: Value,
config: &Config,
) -> Result<AgentPrompt>Run the Lua agent synchronously on a blocking thread.