pub struct ConnectorsConfig {
pub filesystem: HashMap<String, FilesystemConnectorConfig>,
pub git: HashMap<String, GitConnectorConfig>,
pub s3: HashMap<String, S3ConnectorConfig>,
pub script: HashMap<String, ScriptConnectorConfig>,
}Expand description
Container for all connector configurations.
All connector types use named instances — you can configure multiple of each type. For example:
[connectors.git.platform]
url = "https://github.com/acme/platform.git"
[connectors.git.auth-service]
url = "https://github.com/acme/auth-service.git"Use ctx sync git to sync all git connectors, or ctx sync git:platform
for a specific one. ctx sync all syncs everything.
Fields
filesystem: HashMap<String, FilesystemConnectorConfig>Named filesystem connectors: walk local directories.
git: HashMap<String, GitConnectorConfig>Named Git connectors: clone and scan Git repositories.
s3: HashMap<String, S3ConnectorConfig>Named S3 connectors: list and download from S3 buckets.
script: HashMap<String, ScriptConnectorConfig>Named Lua script connectors.
Each key is a connector name, each value contains the script path
and arbitrary config keys passed to the Lua connector.scan() function.
See docs/LUA_CONNECTORS.md for the full specification.