scan_script

Function scan_script 

pub async fn scan_script(
    name: &str,
    script_config: &ScriptConnectorConfig,
) -> Result<Vec<SourceItem>>
Scan a Lua script connector and return the ingested items.

Spawns the Lua VM on a blocking thread to avoid blocking the async runtime. The script’s connector.scan(config) is called with the TOML config section (minus path and timeout) converted to a Lua table.