get_checkpoint

Function get_checkpoint 

async fn get_checkpoint(pool: &SqlitePool, source: &str) -> Result<Option<i64>>
Retrieves the last sync checkpoint for a given connector.

Returns Some(timestamp) if a checkpoint exists, or None if this is the first sync for the connector.