run_sync_with_extensions

Function run_sync_with_extensions 

pub async fn run_sync_with_extensions(
    config: &Config,
    connector: &str,
    full: bool,
    dry_run: bool,
    since: Option<String>,
    until: Option<String>,
    limit: Option<usize>,
    extra_connectors: &ConnectorRegistry,
) -> Result<()>
Runs the ingestion pipeline with additional custom connectors.

Like run_sync, but accepts extra connectors to merge with the built-in ones from config. This is the entry point for custom binaries that register Connector trait implementations.

The extra_connectors are combined with the built-in connectors resolved from the config file.