pub struct McpBridge {
config: Arc<Config>,
tools: Arc<ToolRegistry>,
extra_tools: Arc<ToolRegistry>,
agents: Arc<AgentRegistry>,
extra_agents: Arc<AgentRegistry>,
}Expand description
Bridges the existing registries to the MCP JSON-RPC protocol.
Each MCP session receives a clone of this struct (everything is
behind Arc), so all sessions share the same tool set and agents.
Fields
config: Arc<Config>tools: Arc<ToolRegistry>extra_tools: Arc<ToolRegistry>agents: Arc<AgentRegistry>extra_agents: Arc<AgentRegistry>Implementations
Sourceimpl McpBridge
impl McpBridge
pub fn new( config: Arc<Config>, tools: Arc<ToolRegistry>, extra_tools: Arc<ToolRegistry>, agents: Arc<AgentRegistry>, extra_agents: Arc<AgentRegistry>, ) -> Self
fn find_tool(&self, name: &str) -> Option<&dyn Tool>
fn find_agent(&self, name: &str) -> Option<&dyn Agent>
Sourcefn to_mcp_tool(tool: &dyn Tool) -> Tool
fn to_mcp_tool(tool: &dyn Tool) -> Tool
Convert a context-harness tool into an rmcp Tool descriptor.
Sourcefn to_mcp_prompt(agent: &dyn Agent) -> Prompt
fn to_mcp_prompt(agent: &dyn Agent) -> Prompt
Convert a context-harness agent into an rmcp Prompt descriptor.