fn discover_manifest(registry_dir: &Path) -> RegistryManifestExpand description
Attempt to build a manifest by scanning the directory structure when
no registry.toml is present (e.g. for .ctx/ project-local dirs).
fn discover_manifest(registry_dir: &Path) -> RegistryManifestAttempt to build a manifest by scanning the directory structure when
no registry.toml is present (e.g. for .ctx/ project-local dirs).