pub fn normalize_scores(
candidates: &[ChunkCandidate],
) -> Vec<(&ChunkCandidate, f64)>Expand description
Min-max normalize raw scores to [0.0, 1.0].
If all scores are equal, they are normalized to 1.0.
pub fn normalize_scores(
candidates: &[ChunkCandidate],
) -> Vec<(&ChunkCandidate, f64)>Min-max normalize raw scores to [0.0, 1.0].
If all scores are equal, they are normalized to 1.0.