fn load_or_default(path: &Path) -> Result<WorkspaceRegistry>Expand description
Load the registry from path, or a fresh empty one if the file is absent.
fn load_or_default(path: &Path) -> Result<WorkspaceRegistry>Load the registry from path, or a fresh empty one if the file is absent.