fn write_registry(path: &Path, registry: &WorkspaceRegistry) -> Result<()>Expand description
Persist a registry to disk, creating the parent directory if needed.
fn write_registry(path: &Path, registry: &WorkspaceRegistry) -> Result<()>Persist a registry to disk, creating the parent directory if needed.