pub fn find_local_ctx_dir() -> Option<PathBuf>
Walk from the current directory upward looking for a .ctx/ directory.
.ctx/
Returns the first .ctx/ directory found, or None if the filesystem root is reached without finding one.
None